function obj=randn(varargin)
% FUNCTION fc_amat.random.randn
% -- randn([N,m,n]) or randn([N,m,n],classname)
% -- randn(N,m,n) or randn(N,m,n,classname)
%      Return an N-by-m-by-n amat object with normally distributed random 
%      elements having zero mean and unit standard deviation.
%
% -- randn(N,m) or randn(N,m,classname)
%      Return an N-by-m-by-m amat object with normally distributed random 
%      elements having zero mean and unit standard deviation.
%    
%      Optional classname argument can be used for setting amat object data 
%      type to 'single' or 'double' (default).
%
%      See also: fc_amat.random.rand, fc_amat.random.randi,
%                fc_amat.zeros, fc_amat.ones, fc_amat.eye,
%                class amat
%
  classname='double';
  assert( ismember(nargin,[1,2,3,4]) )
  n=nargin;
  if ischar(varargin{end})
    classname=varargin{end};
    assert( ismember(lower(classname),{'single','double'}) )
    n=n-1;
  end
  switch n
    case 1 % varargin={[N,m,n]} or varargin={[N,m,n],classname}
      S=varargin{1}; assert(length(S)==3)
      N=S(1);m=S(2);n=S(3);
    case 2 % varargin={N,m} or % varargin={N,m,classname}
        N=varargin{1};m=varargin{2};n=m;
    case 3  % varargin={N,m,n} or % varargin={N,m,n,classname}
      N=varargin{1};
      m=varargin{2};
      n=varargin{3};
  end
  obj=amat(randn(N,m,n,classname));
end
